@@ -495,7 +495,7 @@ QString Akonadi::MessageStatus::statusStr() const
         sstr += 'T';
     }
 
-    return QLatin1String(sstr);
+    return QLatin1StringView(sstr);
 }
 
 void Akonadi::MessageStatus::setStatusFromStr(const QString &aStr)
